################################################################################
# info_mds_wp7_netmon_common module						       #
# Paul Mealor, WP7							       #
################################################################################

################################################################################
# Functions available:							       #
#									       #
# glob2pat(glob):							       #
# Convert a shell-style glob to a Perl pattern				       #
#									       #
# hostnameToSite(matchFile,host)					       #
# Convert a hostname (or textual IP) to a site name.			       #
# wp3deploy should be the location of the wp3 deploy directory. This function  #
# reads $matchFile.	       		                                       #
#									       #
# hostnameToNE(matchFile,host)					               #
# Convert a hostname (or textual IP) to a Network element name	       	       #
# wp3deploy should be the location of the wp3 deploy directory. This function  #
# reads $matchFile.                     				       #
#									       #
# ipToHostname(ip)							       #
# Convert an textual ip address to a hostname. Uses gethostbyaddr.	       #
#									       #
################################################################################

################################################################################
# Version history							       #
#									       #
# Date                UID Comment					       #
# 1.0.0									       #
# 21 March 2002       PDM Initial version				       #
################################################################################

package info_mds_wp7_netmon_common;

#From the Perl Cookbook, Oreilly
sub glob2pat {
    my $globstr = shift;
    my %patmap = (
        '.' => '\.',
        '*' => '.*',
        '?' => '.',
        '[' => '[',
        ']' => ']'
    );
    $globstr =~ s{(.)} { $patmap{$1} || "\Q$1" }ge;
    return '^' . $globstr . '$';       #' emacs pattern matching fix :)
}

sub readMatches($$) {
    my ($matches,$filename)=@_;
    my ($toMatch,$site);

    open MATCHES,"<$filename" || die "Failed to open $filename";

    while (<MATCHES>) {
	if (! /^\#|^\s*$/) {
	    ($toMatch,$site) = split(/\s+/,$_,2);
	    chomp($toMatch=&glob2pat($toMatch));
	    chomp($$matches{$toMatch}=$site);
	}
    }
}

my %siteMatches;
#Given the location of the wp3 deploy directory and a hostname,
#map it to a site, using the file $matchFile
sub hostnameToSite($$) {
    my ($matchFile,$hn)=@_;
    #my $matchFile="$wp3deploy/etc/info/wp7-hostnameToSite";
    my $toMatch;

    if ($hn=~/\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/) {
	$hn=&ipToHostname($hn);
	return 0 if !$hn;
    }

    &readMatches(\%siteMatches,$matchFile) if ! %siteMatches;

    foreach $toMatch (keys %siteMatches) {
	return $siteMatches{$toMatch} if ($hn=~$toMatch);
    }

    return 0;
}

my %neMatches;
#Given the location of the wp3 deploy directory and a hostname,
#map it to a NE, using the file $matchFile
sub hostnameToNE($$) {
    my ($matchFile,$hn)=@_;
    #my $matchFile="$wp3deploy/etc/info/wp7-hostnameToNE";
    my $toMatch,$site;

    if ($hn=~/\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/) {
	$hn=&ipToHostname($hn);
	return 0 if !$hn;
    }

    if (! %neMatches) {
	&readMatches(\%neMatches,$matchFile);
	#Remove trailing whitespaces from the NE names
	foreach my $key (keys  %neMatches) {
	    $neMatches{$key}=~s/\s*$//;
	}
    }

    foreach $toMatch (keys %neMatches) {
	return $neMatches{$toMatch} if ($hn=~$toMatch);
    }

    return 0;
}

sub ipToHostname($) {
    my ($ip)=@_;

    my $res = gethostbyaddr(pack("C4",split(/\./,$ip)),2);

    return $res if $res;
    return $ip if !$res;
}

return 1;
